@@ -4,6 +4,6 @@ from camel_model.camel_model import CamelModel
 
 
 class ComponentAttribute(CamelModel):
-    name: str
+    name: Optional[str]
     value: Optional[str]
     observations: Optional[str]
