@@ -2,6 +2,7 @@ from typing import Optional, List
 
 from camel_model.camel_model import CamelModel
 
+from xlsx_lib.domain.smart_key.SmartKeyData import SmartKeyData
 from xlsx_lib.domain.abs.AbsData import AbsData
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisData import AutodiagnosisData
 from xlsx_lib.domain.distribution.distribution_data import DistributionData
@@ -25,3 +26,4 @@ class MotorcycleModel(CamelModel):
     distribution: Optional[DistributionData]
     autodiagnosis: Optional[AutodiagnosisData]
     abs_data: Optional[AbsData]
+    smart_key_data: Optional[SmartKeyData]
\ No newline at end of file
